# arpes.plotting.false\_color module

**arpes.plotting.false\_color.false\_color\_plot(data\_r:
xarray.core.dataset.Dataset, data\_g: xarray.core.dataset.Dataset,
data\_b: xarray.core.dataset.Dataset, ax=None, out=None, invert=False,
pmin=0, pmax=1,**kwargs)\*\*
